function val = Jfunc(arg)

	% Piece-wise approximation taken from:
	% S. ten Brink, G. Kramer, and A. Ashikhmin, “Design of low-density parity-check codes for modulation and detection,” IEEE Trans. Commun., vol. 52, no. 4, pp. 670–678, Apr. 2004.
	
	% Approximation parameters
    sigma_star = 1.6363;
    aj1 = -0.0421061;
    bj1 = 0.209252;
    cj1 = -0.00640081;
    aj2 = 0.00181491;
    bj2 = -0.142675;
    cj2 = -0.0822054;
    dj2 = 0.0549608;
    
    % Preallocate
    val = length(arg);
    
	% Calculate J
    for i = 1:length(arg)
        if( arg(i) >= 0 && arg(i) <= sigma_star )
            val(i) = aj1 * arg(i).^3 + bj1 * arg(i).^2 + cj1*arg(i);
        elseif( arg(i) > sigma_star && arg(i) < 10 )
            val(i) = 1 - exp( aj2 * arg(i).^3 + bj2 * arg(i).^2 + cj2 * arg(i) + dj2 );
        elseif( arg(i) >= 10 )
            val(i) = 1;
        else
            error('Argument must be non-negative')
        end
    end