function val = Jinv(arg)

	% Piece-wise approximation taken from:
	% S. ten Brink, G. Kramer, and A. Ashikhmin, “Design of low-density parity-check codes for modulation and detection,” IEEE Trans. Commun., vol. 52, no. 4, pp. 670–678, Apr. 2004.

	% Approximation parameters
    I_star = 0.3646;    
    as1 = 1.09542;
    bs1 = 0.214217;
    cs1 = 2.33727;    
    as2 = 0.706692;
    bs2 = 0.386013;
    cs2 = -1.75017;
    
    % Preallocate
    val = length(arg);
    
	% Calculate Jinv
    for i = 1:length(arg)
        if( arg(i) <= I_star && arg(i) >= 0)
            val(i) = as1 * arg(i).^2 + bs1 * arg(i) + cs1 * sqrt(arg(i));
        elseif( arg(i) > I_star && arg(i) < 1 )
            val(i) = -as2 * log( bs2*(1 - arg(i)) ) - cs2 * arg(i);
        else
            error('Argument must be in [0,1)'); 
        end
    end