function [ C1, C2, C12 ] = MACapacity(P1, P2, sigma, N)

	% Monte-Carlo based calculation of the symmetric capacity region for the unequal power two-user MAC

	% Create random symbols
	x1 = sign(randn(N,1));
	x2 = sign(randn(N,1));
	y = sqrt(P1)*x1 + sqrt(P2)*x2 + sqrt(sigma)*randn(N,1);

	%% First user (X1)

	% Calculate h_y given x2
	f_y_x2 = ( 1 / ( sqrt( 2 * pi * sigma ) ) ) * ( 0.5*exp( -((y-sqrt(P2)*x2-sqrt(P1)).^2) / (2*sigma) ) + 0.5*exp( -((y-sqrt(P2)*x2+sqrt(P1)).^2) / (2*sigma) ));
	h_y_x2 = -mean(log2(f_y_x2));

	% Calculate h_y_x1_x2
	f_y_x1_x2 = ( 1 / ( sqrt( 2 * pi * sigma ) ) ) * ( exp( -((y-sqrt(P1)*x1-sqrt(P2)*x2).^2) / (2*sigma) ));
	h_y_x1_x2 = -mean(log2(f_y_x1_x2));

	% Calculate capacity
	C1 = h_y_x2 - h_y_x1_x2;

	%% Second user (X2)

	% Calculate h_y given x2
	f_y_x1 = ( 1 / ( sqrt( 2 * pi * sigma ) ) ) * ( 0.5*exp( -((y-sqrt(P2)-sqrt(P1)*x1).^2) / (2*sigma) ) + 0.5*exp( -((y+sqrt(P2)-sqrt(P1)*x1).^2) / (2*sigma) ));
	h_y_x1 = -mean(log2(f_y_x1));

	% Calculate capacity
	C2 = h_y_x1 - h_y_x1_x2;

	%% Both Users

	% Calculate h_y
	f_y = ( 1 / ( sqrt( 2 * pi * sigma ) ) ) * ( 0.25*exp( -((y-sqrt(P2)-sqrt(P1)).^2) / (2*sigma) ) + 0.25*exp( -((y-sqrt(P2)+sqrt(P1)).^2) / (2*sigma) ) + ...
	   0.25*exp( -((y+sqrt(P2)-sqrt(P1)).^2) / (2*sigma) )  + 0.25*exp( -((y+sqrt(P2)+sqrt(P1)).^2) / (2*sigma) ) );
	h_y = -mean(log2(f_y));

	% Calculate capacity
	C12 = h_y - h_y_x1_x2;